==> djangofloor-1.0.0.tar.gz: djangofloor-1.0.0/djangofloor/context_processors.py <==
# -*- coding: utf-8 -*-
"""DjangoFloor's specific context processors
=========================================

Add some values to the template context, related to:

  * (enabled or disabled) default views provided by DjangoFloor,
  * notification objects,
  * authentication provided by HTTP headers,
  * websockets

"""
from __future__ import unicode_literals, print_function, absolute_import

import warnings

from django.conf import settings
from django.contrib.auth.models import AnonymousUser
from djangofloor.models import Notification
from djangofloor.utils import RemovedInDjangoFloor110Warning

__author__ = 'Matthieu Gallet'


def context_base(request):
    """Provide the following variables to templates when you RequestContext:

        * `df_has_index_view`: True if an default index view is included
        * `df_has_login_view`: True if a login view is included
        * `df_has_monitoring_view`: True if the monitoring view is included
        * `df_has_site_search_view`: True if a site-wide search view is provided
        * `df_project_name`: name of your project
        * `df_remote_username`: username provided by a HTTP header
        * `df_remote_authenticated`: True if the user authenticated by a HTTP header
        * `df_get_notifications`: when used, return the list of Notifications of the user
        * `df_user_agent`: user agent provided by the HttpRequest
        * `df_window_key`: a random value provided by each HttpRequest (allowing to identify each browser window)
        * `df_has_ws_topics`: True if some websockets topics are provided to the HttpRequest

    :param request: a HTTP request
    :type request: :class:`django.http.HttpRequest`
    :return: a dict to update the global template context
    :rtype: :class:`dict`
    """
    # noinspection PyTypeChecker
    def df_index_view():
        warnings.warn('df_index_view template value will be removed', RemovedInDjangoFloor110Warning)
        return 'index'

    def df_language_code():
        warnings.warn('df_language_code template value will be removed', RemovedInDjangoFloor110Warning)
        return settings.LANGUAGE_CODE

    def df_user():
        warnings.warn('df_language_code template value will be removed', RemovedInDjangoFloor110Warning)
        return getattr(request, 'user', AnonymousUser())

    return {
        'df_has_index_view': bool(settings.DF_INDEX_VIEW),
        'df_has_login_view': bool(settings.DF_LOGIN_VIEW),
        'df_has_monitoring_view': bool(settings.DF_SYSTEM_CHECKS),
        'df_has_site_search_view': bool(settings.DF_SITE_SEARCH_VIEW),
        'df_project_name': settings.DF_PROJECT_NAME,
        'df_remote_username': getattr(request, 'remote_username', None),
        'df_remote_authenticated': bool(getattr(request, 'remote_username', None)),
        'df_user': df_user,
        'df_get_notifications': lambda: Notification.get_notifications(request),
        'df_user_agent': request.META.get('HTTP_USER_AGENT', ''),
        'df_window_key': getattr(request, 'window_key', None),
        'df_session_id': request.COOKIES.get(settings.SESSION_COOKIE_NAME),
        'df_has_ws_topics': getattr(request, 'has_websocket_topics', False),
        'df_http_request': request,
        'df_index_view': df_index_view,
        'df_language_code': df_language_code,
    }

==> djangofloor-1.0.19.tar.gz: djangofloor-1.0.19/djangofloor/context_processors.py <==
"""DjangoFloor's specific context processors
=========================================

Add some values to the template context, related to:

  * (enabled or disabled) default views provided by DjangoFloor,
  * notification objects,
  * authentication provided by HTTP headers,
  * websockets

"""
import warnings

from django.conf import settings
from django.contrib.auth.models import AnonymousUser
from djangofloor.models import Notification
from djangofloor.utils import RemovedInDjangoFloor110Warning

__author__ = 'Matthieu Gallet'


def context_base(request):
    """Provide the following variables to templates when you RequestContext:

        * `df_has_index_view`: True if an default index view is included
        * `df_has_login_view`: True if a login view is included
        * `df_has_monitoring_view`: True if the monitoring view is included
        * `df_has_site_search_view`: True if a site-wide search view is provided
        * `df_project_name`: name of your project
        * `df_remote_username`: username provided by a HTTP header
        * `df_remote_authenticated`: True if the user authenticated by a HTTP header
        * `df_get_notifications`: when used, return the list of Notifications of the user
        * `df_user_agent`: user agent provided by the HttpRequest
        * `df_window_key`: a random value provided by each HttpRequest (allowing to identify each browser window)
        * `df_has_ws_topics`: True if some websockets topics are provided to the HttpRequest

    :param request: a HTTP request
    :type request: :class:`django.http.HttpRequest`
    :return: a dict to update the global template context
    :rtype: :class:`dict`
    """
    # noinspection PyTypeChecker
    def df_index_view():
        warnings.warn('"df_index_view" template value will be removed, use "df_has_index_view" instead.',
                      RemovedInDjangoFloor110Warning)
        return 'index'

    def df_language_code():
        warnings.warn('"df_language_code" template value will be removed, use "LANGUAGE_CODE" (provided by '
                      '"django.template.context_processors.i18n") instead.', RemovedInDjangoFloor110Warning)
        return settings.LANGUAGE_CODE

    def df_user():
        warnings.warn('"df_user" template value will be removed, use "user" (provided by '
                      '"django.contrib.auth.context_processors.auth") instead.', RemovedInDjangoFloor110Warning)
        return getattr(request, 'user', AnonymousUser())

    return {
        'df_has_index_view': bool(settings.DF_INDEX_VIEW),
        'df_has_login_view': bool(settings.DF_LOGIN_VIEW),
        'df_has_monitoring_view': bool(settings.DF_SYSTEM_CHECKS),
        'df_has_site_search_view': bool(settings.DF_SITE_SEARCH_VIEW),
        'df_project_name': settings.DF_PROJECT_NAME,
        'df_remote_username': getattr(request, 'remote_username', None),
        'df_remote_authenticated': bool(getattr(request, 'remote_username', None)),
        'df_user': df_user,
        'df_get_notifications': lambda: Notification.get_notifications(request),
        'df_user_agent': request.META.get('HTTP_USER_AGENT', ''),
        'df_window_key': getattr(request, 'window_key', None),
        'df_session_id': request.COOKIES.get(settings.SESSION_COOKIE_NAME),
        'df_has_ws_topics': getattr(request, 'has_websocket_topics', False),
        'df_http_request': request,
        'df_index_view': df_index_view,
        'df_language_code': df_language_code,
    }
